Predefined nodes
================

Preparing data for plotting
---------------------------

Data Selection
^^^^^^^^^^^^^^

To be written. Describe data selector, idea of compatible data.

Data Gridding
^^^^^^^^^^^^^

Converting data from a tabular format to a grid is done by the by the node class :class:`.DataGridder`:


.. autoclass:: plottr.node.grid.DataGridder
    :members: grid

.. autoclass:: plottr.node.grid.GridOption
    :members:


Data slicing and reduction to 1D or 2D
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

To be written.
